EntitySystemSystemParamFunction

Struct EntitySystemSystemParamFunction 

pub struct EntitySystemSystemParamFunction<T: EntitySystem<In: Clone, Out = ()>>(pub T);
SystemParamFunction, every time it’s run, it iterates over all the entities in the world that T can run on and runs T for them. Input will be cloned for every run of T.

Tuple Fields

0: T