pub struct EntitySystemSystemParamFunction<T: EntitySystem<In: Clone, Out = ()>>(pub T);Expand description
SystemParamFunction, every time it’s run, it iterates over all the
entities in the world that T can run on
and runs T for them. Input will be cloned for every run of T.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: EntitySystem<In: Clone, Out = ()>> SystemParamFunction<IsEntitySystem> for EntitySystemSystemParamFunction<T>
impl<T: EntitySystem<In: Clone, Out = ()>> SystemParamFunction<IsEntitySystem> for EntitySystemSystemParamFunction<T>
Sourcetype In = <T as EntitySystem>::In
type In = <T as EntitySystem>::In
The input type to this system. See
System::In.Sourcetype Out = ()
type Out = ()
The return type of this system. See
System::Out.Sourcetype Param = (Query<'static, 'static, <T as EntitySystem>::Data, <T as EntitySystem>::Filter>, ParamSet<'static, 'static, (<T as EntitySystem>::Param,)>)
type Param = (Query<'static, 'static, <T as EntitySystem>::Data, <T as EntitySystem>::Filter>, ParamSet<'static, 'static, (<T as EntitySystem>::Param,)>)
The
SystemParam/s used by this system to access the World.Sourcefn run(
&mut self,
input: Self::In,
param_value: SystemParamItem<'_, '_, Self::Param>,
) -> Self::Out
fn run( &mut self, input: Self::In, param_value: SystemParamItem<'_, '_, Self::Param>, ) -> Self::Out
Executes this system once. See
System::run or System::run_unsafe.Auto Trait Implementations
impl<T> Freeze for EntitySystemSystemParamFunction<T>
impl<T> RefUnwindSafe for EntitySystemSystemParamFunction<T>
impl<T> Send for EntitySystemSystemParamFunction<T>
impl<T> Sync for EntitySystemSystemParamFunction<T>
impl<T> Unpin for EntitySystemSystemParamFunction<T>
impl<T> UnwindSafe for EntitySystemSystemParamFunction<T>